Release History
===============

1.0.0.beta.2
============

* Major code optimizations by old salty sea dog Terry Jones.
* A more terrifying logo by Cap'n Steve "Inkspot" Hawkes.
* Addition of a code of mis-conduct (for Pirates) by terror of the seas, Tim
  "No beard" Golden.

1.0.0.beta.1
============

* Minor documentation fixes.
* Minor corrections in the code.

1.0.0.alpha.1
=============

* Initial release.
* Very simple implementation.
* Documentation.
* No tests.
